# Load the XML file
$xml = [xml](Get-Content "extract.pxf") # Replace with your actual file path

# Create a namespace manager
$namespaceManager = New-Object System.Xml.XmlNamespaceManager($xml.NameTable)
$namespaceManager.AddNamespace("cc", "http://colorexchangeformat.com/CxF3-core") # Correct namespace URI from your XML

# Create a CSV object
$csv = @()

# Iterate through <cc:Object> elements
foreach ($object in $xml.DocumentElement.SelectNodes("//cc:Object", $namespaceManager)) {
    # Extract values
    $id = $object.Attributes["Id"].Value
    $rNode = $object.SelectSingleNode(".//cc:R", $namespaceManager)
    $gNode = $object.SelectSingleNode(".//cc:G", $namespaceManager)
    $bNode = $object.SelectSingleNode(".//cc:B", $namespaceManager)

    # Handle missing nodes gracefully
    $r = if ($rNode) { $rNode.InnerText } else { "" }
    $g = if ($gNode) { $gNode.InnerText } else { "" }
    $b = if ($bNode) { $bNode.InnerText } else { "" }

    # Add to CSV
    $csv += [PSCustomObject]@{
        ID = $id
        R  = $r
        G  = $g
        B  = $b
    }
}

# Export to CSV
$csv | Export-Csv -Path "output.csv" -NoTypeInformation

Write-Host "Data has been successfully written to output.csv!"
